=======
History
=======

0.1.4 (2019-11-29)
------------------

* Add calculation of weight fractions for trace elements.

0.1.2 (2017-06-26)
------------------

* Add create multi-layers specimen.
* Add number of layers X, Y, and Z as parameters.

0.1.0 (2017-03-07)
------------------

* First release on PyPI.
